@@ -1,8 +1,12 @@
 from ._BoolSerialiser import BoolSerialiser
+from ._DictSerialiser import DictSerialiser
 from ._FixedLengthStringSerialiser import FixedLengthStringSerialiser
 from ._FloatSerialiser import FloatSerialiser
 from ._IntSerialiser import IntSerialiser
+from ._LengthPrefixedBytesSerialiser import LengthPrefixedBytesSerialiser
 from ._LengthPrefixedStringSerialiser import LengthPrefixedStringSerialiser
+from ._ListSerialiser import ListSerialiser
 from ._NullTerminatedStringSerialiser import NullTerminatedStringSerialiser
 from ._SecondsSinceEpochSerialiser import SecondsSinceEpochSerialiser
 from ._StringSerialiser import StringSerialiser, NULL_BYTE
+from ._TupleSerialiser import TupleSerialiser
